<?php

namespace App\Http\Controllers\Users;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Setting;
use App\Models\AuthUser;
use Session;
use Validator;
use Illuminate\Support\Facades\Hash;
use Yajra\DataTables\Facades\DataTables;
use DB;
use App\Models\Role;
use Mail;

class AuthUserController extends Controller
{
	
    public function __construct() {
        $this->middleware('guest', ['except' => 'logout']);
    }
    
    public function view(){
        $data['title'] = 'Manage Authorize User';
        $data['class'] = 'Authorize User';
        $data['table'] = 'Manage Authorize User';
        return view("users.auth.list",$data);
    }

    public function listView(){
        $user_id = Session::get('site_user_id');
        return DataTables::of(AuthUser::where('user_id' , $user_id))
                ->addColumn('action', function($data){
                    return "<a href='".url('/')."/user/auth/edit/".$data->id."'  class='all_button btn  btn-sm btn-info'  id='".$data->id."'>Edit</a><a href='javascript:void(0)' class='all_button btn btn-sm btn-danger delete_btn'  data-value='".$data."' id='".$data->id."'>Delete</a>";
                })->make(true);;
    }
    
    public function create(Request $request){
        $data['title'] = 'Add Authorize User';
        $data['class'] = 'Authorize User';
        $data['table'] = 'Add Authorize User';
        $user_id = Session::get('site_user_id');
        $mailbox = User::where('user_id' , $user_id)->first()->mailbox;
        if ($request->isMethod('get')) {
            $data['mailbox'] = $mailbox;
            $data['users'] = User::where('role_id' , 0)->get();
            return view('users/auth/create' , $data);
        }else{
            $validator = Validator::make($request->all(), [
                                'name' => 'required',
                                'phone' => 'required',
                                'proof' => 'required'
                            ]);
            if ($validator->fails()) {
                    return redirect('user/auth/add')
                                    ->withInput()
                                    ->withErrors($validator);
            }else{
                $purchase = new AuthUser();
                $purchase->user_id = $user_id;
                $purchase->name = $request->name;
                $purchase->phone = $request->phone;
                $purchase->proof = $request->proof;
                $purchase->created_at = date('Y-m-d h:i:s');
                $purchase->updated_at = date('Y-m-d h:i:s');
                $purchase->save();
                
                 Session::flash('success_msg', 'User has been saved successfully.'); 
                return redirect('user/auth/list');
                
            }
        }
    }
    
    public function edit(Request $request , $id = ''){
        $data['title'] = 'Update Authorize User';
        $data['class'] = 'Authorize User';
        $data['table'] = 'Update Authorize User';
        $user_id = Session::get('site_user_id');
        $mailbox = User::where('user_id' , $user_id)->first()->mailbox;
        if ($request->isMethod('get')) {
            $data['mailbox'] = $mailbox;
            $data['users'] = User::where('role_id' , 0)->get();
            $data['purchase'] = AuthUser::where('id' , $id)->first();
            return view('users/auth/edit' , $data);
        }else{
            $validator = Validator::make($request->all(), [
                            'name' => 'required',
                            'phone' => 'required',
                            'proof' => 'required'
                        ]);
            if ($validator->fails()) {
                return redirect('user/auth/edit/'.$id)
                            ->withInput()
                            ->withErrors($validator);
            }else{
                AuthUser::where('id', $id)
                        ->update([
                            'name' => $request->name,
                            'phone' => $request->phone,
                            'proof' => $request->proof
                        ]);
                Session::flash('success_msg', 'User has been updated successfully.'); 
                return redirect('user/auth/list');
            }
        }
    }
    public function viewUser(){
        //return session('site_user_id');
        $data['title'] = 'Referral Users';
        $data['class'] = 'users';
        $data['table'] = 'Referral Users';

        return view("users/users.ref_list",$data);
    }

    public function listViewUser()
    {
        $user = User::where('user_id' , session('site_user_id'))->first();
        return DataTables::of(User::where('ref_by' , $user->referral_code))
                ->addColumn('pending_balance', function ($query) {
                    $c_user_id = session('site_user_id');
                    $credit_ref_points = DB::table('member_referral_points')->where('from_user_id' , $c_user_id)->where('user_id' , $query->user_id)->where('status' , 1)->where('type' , 1)->sum('balance');
                    $debit_ref_points = DB::table('member_referral_points')->where('from_user_id' , $c_user_id)->where('user_id' , $query->user_id)->where('status' , 0)->where('type' , 2)->sum('balance');
                    
                    $pending_balance = DB::table('member_referral_points')->where('from_user_id' , $c_user_id)->where('user_id', $query->user_id)->where('status' , 0)->where('type' , 1)->sum('balance');
                    $available_balance = $credit_ref_points - $debit_ref_points;
                    $btn = '';
                    $btn .='<label for="exampleInputEmail1" class=" col-lg-12" style="text-align: left;padding-left: 0px;">Pending Balance - $<span>'.number_format($pending_balance,2).'</span></label>';
                    return $btn;
                })
                ->addColumn('available_balance', function ($query) {
                    $c_user_id = session('site_user_id');
                    $credit_ref_points = DB::table('member_referral_points')->where('from_user_id' , $c_user_id)->where('user_id' , $query->user_id)->where('status' , 1)->where('type' , 1)->sum('balance');
                    $debit_ref_points = DB::table('member_referral_points')->where('from_user_id' , $c_user_id)->where('user_id' , $query->user_id)->where('status' , 0)->where('type' , 2)->sum('balance');
                    
                    $pending_balance = DB::table('member_referral_points')->where('from_user_id' , $c_user_id)->where('user_id', $query->user_id)->where('status' , 0)->where('type' , 1)->sum('balance');
                    $available_balance = $credit_ref_points - $debit_ref_points;
                    $btn = '';
                    $btn .= '<label for="exampleInputEmail1" class=" col-lg-12" style="text-align: left; padding-left: 0px;">Available Balance - $<span id="available_balance">'.number_format($available_balance,2).'</span></label>';
                    return $btn;
                })
                ->addColumn('description', function ($query) {
                    $setting = Setting::first();
                    $package_weight = DB::table('transactions_referral')->where('mailbox' , $query->mailbox)->sum('weight');
                    $package_count = DB::table('transactions_referral')->where('mailbox' , $query->mailbox)->count();
                    return 'Earn money from us! With every '.$setting->reffral_packages.' packages shipped or a weight of '.$setting->reffral_weight.'lbs  you will get '.$setting->referral_amount.'USD to your account. currently you shipped '.$package_count.' packages weight '.$package_weight.'lbs.';
                })
                ->rawColumns(['action' => 'action',"pending_balance"=>"pending_balance","available_balance"=>"available_balance","description" => "description"])
                ->addColumn('action', function($data){
                    $btn = '';
                    $c_user_id = session('site_user_id');
                    $pending_balance = DB::table('member_referral_points')->where('from_user_id' , $c_user_id)->where('user_id', $data->user_id)->where('status' , 0)->where('type' , 1)->sum('balance');
                    if($pending_balance > 0){
                        $btn .=  "<a href='javascript:void(0)'  class='all_button btn  btn-sm btn-warning' data-value='".$data."' id='".$data->user_id."'>Pending</a>";
                    }else{
                        $btn .=  "<a href='javascript:void(0)'  class='all_button btn  btn-sm btn-success' data-value='".$data."' id='".$data->user_id."'>Completed</a>";
                    }
                    
                    return $btn;
                })->make(true);
    }
    public function delete(){
        AuthUser::where(["id"=>request()->id])->delete();
        return ["status" => true,"message" =>"Record deleted successfully"];
    }
    
}
